# -------------------------------------------------------------
# Applied Statistics / Statistical methods in the Biosciences
# Design of experiments: 
#   1) Half fraction factorial design
#   2) Plackett-Burman design
# Bo Markussen
# December 31, 2021
# -------------------------------------------------------------

# Example from lecture ----

# load libraries
library(AlgDesign)

# Make full factorial design for 5 factors on 2 levels each
full.factorial <- gen.factorial(levels=2,nVars=5,varNames=c("FeedRate","Catalyst","AgitRate","Temp","Conc"))
full.factorial

# Make a design with 16 units 
# for main effects and 2-way interactions between 5 factors on 2 levels
optFederov(~(FeedRate+Catalyst+AgitRate+Temp+Conc)^2,data=full.factorial,nTrials=16)$design

# An error message is given if you try to make a design with too few experimental units
optFederov(~(FeedRate+Catalyst+AgitRate+Temp+Conc)^2,data=full.factorial,nTrials=15)$design


# Plackett-Burman design with 12 experimental runs ----

library(FrF2)
pb(12)
